@@ -33,9 +33,9 @@ class QLabel;
 class BoolParameter : public AbstractParameter {
   Q_OBJECT
 public:
-  BoolParameter(QObject * parent = 0);
+  BoolParameter(QObject * parent = nullptr);
   ~BoolParameter();
-  void addTo(QWidget *, int row) override;
+  bool addTo(QWidget *, int row) override;
   QString textValue() const override;
   void setValue(const QString & value) override;
   void reset() override;
