@@ -1,5 +1,5 @@
 /** -*- mode: c++ ; c-basic-offset: 2 -*-
- * @file   View2DWidget.h
+ * @file   ImageView.h
  * @author Sebastien Fourey
  * @date   July 2010
  * @brief  Declaration of the class ImageFilter
@@ -46,19 +46,25 @@
 #ifndef _IMAGEVIEW_H_
 #define _IMAGEVIEW_H_
 
-#include <QWidget>
 #include <QMutex>
+#include <QTime>
+#include <QWidget>
+#include "KeypointList.h"
 
 class QPaintEvent;
 
 class ImageView : public QWidget {
-  Q_OBJECT;
+  Q_OBJECT
 
 public:
-  ImageView( QWidget * parent = 0 );
+  ImageView(QWidget * parent = 0);
   inline QImage & image();
   inline QMutex & imageMutex();
   void setImageSize(int width, int height);
+  void setBackgroundColor(QColor);
+  void setKeypoints(const KeypointList & keypoints);
+  KeypointList keypoints() const;
+  QRect imagePosition();
 
 public slots:
   void zoomOriginal();
@@ -66,40 +72,50 @@ public slots:
   void checkSize();
 
 protected:
-  void paintEvent( QPaintEvent * );
-  void mousePressEvent( QMouseEvent * );
-  void mouseReleaseEvent( QMouseEvent * );
+  void paintEvent(QPaintEvent *);
+  void mousePressEvent(QMouseEvent *);
+  void mouseReleaseEvent(QMouseEvent *);
   void mouseDoubleClickEvent(QMouseEvent *);
-  void mouseMoveEvent( QMouseEvent * );
-  void resizeEvent ( QResizeEvent * );
-  void keyPressEvent( QKeyEvent * );
-  void closeEvent( QCloseEvent * );
+  void mouseMoveEvent(QMouseEvent *);
+  void resizeEvent(QResizeEvent *);
+  void keyPressEvent(QKeyEvent *);
+  void closeEvent(QCloseEvent *);
 
 signals:
-  void mousePress( QMouseEvent * );
-  void mouseMove( QMouseEvent * );
-  void mouseDoubleClick( QMouseEvent * );
+  void mousePress(QMouseEvent *);
+  void mouseMove(QMouseEvent *);
+  void mouseDoubleClick(QMouseEvent *);
   void aboutToClose();
   void spaceBarPressed();
   void escapePressed();
+  void keypointPositionsChanged();
+  void resized(QSize);
 
 private:
-  QMouseEvent mapMousePositionToImage( QMouseEvent * e );
+  QMouseEvent mapMousePositionToImage(QMouseEvent * e);
   QImage _image;
   QMutex _imageMutex;
   QRect _imagePosition;
   double _scaleFactor;
   bool _zoomOriginal;
+  QColor _backgroundColor;
+  KeypointList _keypoints;
+  int _movedKeypointIndex;
+  QTime _keypointTimestamp;
+  static int roundedDistance(const QPoint & p1, const QPoint & p2);
+  int keypointUnderMouse(const QPoint & p);
+  void paintKeypoints(QPainter & painter);
+  QPoint keypointToPointInWidget(const KeypointList::Keypoint & kp) const;
+  QPoint keypointToVisiblePointInWidget(const KeypointList::Keypoint & kp) const;
+  QPointF pointInWidgetToKeypointPosition(const QPoint & p) const;
 };
 
-QImage &
-ImageView::image()
+QImage & ImageView::image()
 {
   return _image;
 }
 
-QMutex &
-ImageView::imageMutex()
+QMutex & ImageView::imageMutex()
 {
   return _imageMutex;
 }
